GenericSQLVirtualServerModel

Struct GenericSQLVirtualServerModel 

pub struct GenericSQLVirtualServerModel { /* private fields */ }
JavaScript-facing DuckDB SQL query builder.

This struct wraps the Rust DuckDBSqlBuilder and exposes it to JavaScript via wasm_bindgen.

Implementations

Source

impl GenericSQLVirtualServerModel

pub fn new( args: Option<JsGenericSQLVirtualServerModelArgs>, ) -> Result<Self, JsValue>

Creates a new JsDuckDBSqlBuilder instance.

pub fn get_hosted_tables(&self) -> Result<String, JsValue>

Returns the SQL query to list all hosted tables.

pub fn table_schema(&self, table_id: &str) -> Result<String, JsValue>

Returns the SQL query to describe a table’s schema.

pub fn table_size(&self, table_id: &str) -> Result<String, JsValue>

Returns the SQL query to get the row count of a table.

pub fn view_column_size(&self, view_id: &str) -> Result<String, JsValue>

Returns the SQL query to get the column count of a view.

pub fn table_validate_expression( &self, table_id: &str, expression: &str, ) -> Result<String, JsValue>

Returns the SQL query to validate an expression against a table.

pub fn view_delete(&self, view_id: &str) -> Result<String, JsValue>

Returns the SQL query to delete a view.

pub fn table_make_view( &self, table_id: &str, view_id: &str, config: JsValue, ) -> Result<String, JsValue>

Returns the SQL query to create a view from a table with the given configuration.

pub fn view_get_data( &self, view_id: &str, config: JsValue, viewport: JsValue, schema: JsValue, ) -> Result<String, JsValue>

Returns the SQL query to fetch data from a view with the given viewport.

pub fn view_schema(&self, view_id: &str) -> Result<String, JsValue>

Returns the SQL query to describe a view’s schema.

pub fn view_size(&self, view_id: &str) -> Result<String, JsValue>

Returns the SQL query to get the row count of a view.

pub fn view_get_min_max( &self, view_id: &str, column_name: &str, config: JsValue, ) -> Result<String, JsValue>

Returns the SQL query to get the min and max values of a column.